# Randon

Developed by Roop Majumder from Technical Earth (c) 2020

## Examples of How To Use

using intrand

```python
from randon import intrand

intrand()
```

using floatrand

```python
from randon import floatrand

floatrand()
```

##there are more to explore stay around